@@ -642,6 +642,12 @@ gboolean file_is_image (const gchar *name,
 }
 
 
+gboolean mime_type_is_video (const char *mime_type)
+{
+	return (strstr (mime_type, "video") != NULL);
+}
+
+
 gboolean file_is_video (const gchar *name,
                         gboolean     fast_file_type)
 {
@@ -655,13 +661,26 @@ gboolean file_is_video (const gchar *name,
 }
 
 
-gboolean mime_type_is_video (const char *mime_type)
+gboolean mime_type_is_audio (const char *mime_type)
 {
-	return (strstr (mime_type, "video") != NULL);
+        return (strstr (mime_type, "audio") != NULL);
 }
 
 
-gboolean file_is_image_or_video (const gchar *name,
+gboolean file_is_audio (const gchar *name,
+                        gboolean     fast_file_type)
+{
+        const char *mime_type = NULL;
+
+        mime_type = get_file_mime_type (name, fast_file_type);
+        if (mime_type == NULL)
+                return FALSE;
+
+        return mime_type_is_audio (mime_type);
+}
+
+
+gboolean file_is_image_video_or_audio (const gchar *name,
                                  gboolean     fast_file_type)
 {
         const char *mime_type = NULL;
@@ -670,7 +689,9 @@ gboolean file_is_image_or_video (const gchar *name,
         if (mime_type == NULL)
                 return FALSE;
 
-        return mime_type_is_image (mime_type) || mime_type_is_video (mime_type);
+        return mime_type_is_image (mime_type) ||
+	       mime_type_is_video (mime_type) ||
+	       mime_type_is_audio (mime_type);
 }
 
 
@@ -796,22 +817,35 @@ get_file_mime_type (const char *filename,
 		result = gnome_vfs_get_file_mime_type (filename, NULL, FALSE);
 	}
 
+	const char *extension = get_filename_extension (filename);
 
-	/* If the file extension is not recognized, or the content is
-	   determined to be binary data (octet-stream), check for HDR file
-	   types, which are not well represented in the freedesktop mime
-	   database currently. This section can be purged when they are.
-	   This is an unpleasant hack. Some file extensions
-	   may be missing here; please file a bug if they are. */
+	/* Check files with special or problematic extensions */
+	if (extension != NULL) {
 
-	if ( (result==NULL) ||
-	     !strcmp (result, "application/octet-stream")) {
-		const char *extension = get_filename_extension (filename);
-		if (extension != NULL) {
+		/* Raw NEF files are sometimes mis-recognized as tiff files. Fix that. */
+		if (!strcmp (result,"image/tiff") && !strcasecmp (extension, "nef"))
+			return "image/x-nikon-nef";
+
+		/* Check unrecognized binary types for special types that are not
+		   handled correctly in the normal mime databases. */
+
+		if ( (result==NULL) || !strcmp (result, "application/octet-stream")) {
+
+			/* If the file extension is not recognized, or the content is
+			   determined to be binary data (octet-stream), check for HDR file
+			   types, which are not well represented in the freedesktop mime
+			   database currently. This section can be purged when they are.
+			   This is an unpleasant hack. Some file extensions
+			   may be missing here; please file a bug if they are. */
 			if (   !strcasecmp (extension, "exr")	/* OpenEXR format */
 			    || !strcasecmp (extension, "hdr")	/* Radiance rgbe */
 			    || !strcasecmp (extension, "pic"))	/* Radiance rgbe */
 				return "image/x-hdr";
+
+			/* Bug 329072: gnome-vfs doesn't recognize pcx files.
+			   This is the work-around until bug 329072 is fixed. */
+			if ( !strcasecmp (extension, "pcx") )
+				return "image/x-pcx";
 		}
 	}
 
@@ -2362,7 +2396,9 @@ copy_cache_file_to_remote_uri (const char *local_filename,
 
 static GdkPixbuf*
 get_pixbuf_using_external_converter (const char *url,
-				     const char *mime_type)
+				     const char *mime_type,
+				     int requested_width_if_used,
+				     int requested_height_if_used)
 {
 	char       *path;
 	char	   *cache_file;
@@ -2373,20 +2409,24 @@ get_pixbuf_using_external_converter (const char *url,
 	char	   *command;
 	GdkPixbuf  *pixbuf = NULL;
 	gboolean    is_raw;
+	gboolean    is_hdr;
 
 	path = gnome_vfs_unescape_string (url, NULL);
 
 	is_raw = mime_type_is_raw (mime_type);
+	is_hdr = !is_raw;
 
 	md5_file = gnome_thumbnail_md5 (path);
 
 	input_file_esc = shell_escape (path);
 
 	if (is_raw)
-		/* pnm is dcraw's default output format */
+		/* Same file used for RAW thumbnailing and full image loading */
 		cache_file_full = get_cache_full_path (md5_file, "conv.pnm");
+	else if (requested_width_if_used > 0)
+		/* HDR: separate files for thumbnails, full images */
+		cache_file_full = get_cache_full_path (md5_file, "conv-thumb.tiff");
 	else
-		/* what's best for pfstools? tiff or png? */
 		cache_file_full = get_cache_full_path (md5_file, "conv.tiff");
 
 	cache_file = g_strdup (remove_scheme_from_uri (cache_file_full));
@@ -2405,28 +2445,52 @@ get_pixbuf_using_external_converter (const char *url,
 	/* Do nothing if an up-to-date converted file is already in the cache */
         if (!path_is_file (cache_file) ||
             (get_file_mtime (path) > get_file_mtime (cache_file))) {
-		if ( is_raw ) {
-			/* raw files */
+
+		if (is_raw) {
+			/* RAW files - dcraw doesn't support thumbnailing very
+			   elegantly (even with the -e option), so we just convert
+			   the full file (which will speed up image loading). */
 		        command = g_strconcat ( "dcraw -c ",
         	        	                input_file_esc,
                 	        	        " > ",
                         	        	cache_file_esc,
                                 		NULL );
 		} else {
-			/* hdr files */
+			/* HDR files. We can use the pfssize tool to speed up
+			   thumbnail generation considerably, so we treat
+			   thumbnailing as a special case. */
+			char *resize_command;
+
+			if (requested_width_if_used > 0)
+				resize_command = g_strdup_printf (" | pfssize --maxx %d --maxy %d",
+						                  requested_width_if_used,
+								  requested_height_if_used);
+			else
+				resize_command = g_strdup_printf (" ");
+
         	        command = g_strconcat ( "pfsin ",
                 	                        input_file_esc,
+						resize_command,
                         	                " |  pfsclamp  --rgb  | pfstmo_drago03 | pfsout ",
                                 	        cache_file_esc,
                                         	NULL );
+			g_free (resize_command);
 		}
-	       	system (command);
+
+		if (gnome_vfs_is_executable_command_string (command))
+		       	system (command);
+
         	g_free (command);
 	}
 
 	if (path_is_file (cache_file))
 		pixbuf = gdk_pixbuf_new_from_file (cache_file, NULL);
 
+	/* Thumbnail files are already cached, so delete the conversion cache 
+	   copies of HDR files. */
+	if (requested_width_if_used > 0 && is_hdr)
+		file_unlink (cache_file);
+
 	g_free (cache_file);
         g_free (cache_file_esc);
         g_free (input_file_esc);
@@ -2443,30 +2507,41 @@ gth_pixbuf_new_from_video (const char             *path,
 {
       	GdkPixbuf *pixbuf = NULL;
 	time_t     mtime;
+	char      *real_path = NULL;
         char      *existing_video_thumbnail;
 
-        /* use the gnome thumbnailer for videos */
-        mtime = get_file_mtime (path);
+	if (resolve_all_symlinks (path, &real_path) != GNOME_VFS_OK)
+		return NULL;
 
+        mtime = get_file_mtime (real_path);
         existing_video_thumbnail = gnome_thumbnail_factory_lookup (factory,
-                                                                   path,
+                                                                   real_path,
                                                                    mtime);
 
 	if (existing_video_thumbnail != NULL) {
-		pixbuf = gdk_pixbuf_new_from_file (existing_video_thumbnail,
-						   error);
+		char *thumbnail_path = get_local_path_from_uri (existing_video_thumbnail);
+
+		pixbuf = gdk_pixbuf_new_from_file (thumbnail_path, error);
+		g_free (thumbnail_path);
                 g_free (existing_video_thumbnail);
-        } else {
+        }
+        else if (gnome_thumbnail_factory_has_valid_failed_thumbnail (factory, real_path, mtime)) {
+		g_free (real_path);
+        	return NULL;
+	}
+	else {
 		pixbuf = gnome_thumbnail_factory_generate_thumbnail (factory,
-                                                                     path,
-                                                                     get_mime_type (path));
+                                                                     real_path,
+                                                                     get_mime_type (real_path));
                 if (pixbuf != NULL)
 			gnome_thumbnail_factory_save_thumbnail (factory,
                                                                 pixbuf,
-                                                                path,
+                                                                real_path,
                                                                 mtime);
 	}
 
+	g_free (real_path);
+
         return pixbuf;
 }
 
@@ -2494,18 +2569,20 @@ gth_pixbuf_new_from_uri (const char  *uri,
 		mime_type = get_file_mime_type (local_file, eel_gconf_get_boolean (PREF_FAST_FILE_TYPE, TRUE));
 
 #ifdef HAVE_LIBOPENRAW
-	/* raw thumbnails */
-	if ((pixbuf == NULL) && 
+	/* Raw thumbnails - using libopenraw is much faster than using dcraw for
+	   thumbnails. Use libopenraw for full raw images too, once it matures. */
+	if ((pixbuf == NULL) &&
 	    mime_type_is_raw (mime_type) && (requested_width_if_used > 0))
 		pixbuf = or_gdkpixbuf_extract_thumbnail (local_file, requested_width_if_used);
 #endif
 
-	/* Use dcraw for raw images (non-thumbnails) and pfstools for HDR images.
-	   Use libopenraw preferentially in the future for raw images, once
-	   it matures. */
+	/* Use dcraw for raw images and pfstools for HDR images. */
 	if ((pixbuf == NULL) &&
 	    (mime_type_is_raw (mime_type) || mime_type_is_hdr (mime_type)))
-		pixbuf = get_pixbuf_using_external_converter (local_file, mime_type);
+		pixbuf = get_pixbuf_using_external_converter (local_file, 
+							      mime_type,
+							      requested_width_if_used,
+							      requested_height_if_used);
 
 	/* Otherwise, use standard gdk_pixbuf loaders */
         if (pixbuf == NULL)
@@ -2517,12 +2594,12 @@ gth_pixbuf_new_from_uri (const char  *uri,
 
 
 GdkPixbufAnimation*
-gth_pixbuf_animation_new_from_uri (const char 	         *filename,
-				   GError               **error,
-				   gint		          requested_width_if_used,
-				   gint		          requested_height_if_used,
-				   GnomeThumbnailFactory *factory,
-				   const char            *mime_type)
+gth_pixbuf_animation_new_from_uri (const char 	          *filename,
+				   GError                **error,
+				   gint		           requested_width_if_used,
+				   gint		           requested_height_if_used,
+				   GnomeThumbnailFactory  *factory,
+				   const char             *mime_type)
 {
 	GdkPixbufAnimation *animation = NULL;
 	GdkPixbuf          *pixbuf = NULL;
@@ -2532,6 +2609,7 @@ gth_pixbuf_animation_new_from_uri (const char 	         *filename,
 		return NULL;
 
         /* The video thumbnailer can handle VFS URIs directly */
+
         if (mime_type_is_video (mime_type) && (factory != NULL)) {
 		pixbuf = gth_pixbuf_new_from_video (filename, factory, error);
 		if (pixbuf == NULL)
@@ -2577,7 +2655,7 @@ gth_pixbuf_animation_new_from_uri (const char 	         *filename,
 	   non-animated pixbuf, and convert to a single-frame animation. */
 	if (pixbuf == NULL) {
 		char *local_uri = escape_uri(local_file);
-	        pixbuf = gth_pixbuf_new_from_uri (local_uri, 
+	        pixbuf = gth_pixbuf_new_from_uri (local_uri,
 				                  error,
 						  requested_width_if_used,
 						  requested_height_if_used,
