@@ -1056,7 +1056,9 @@ load_new_list (GthFileList *file_list)
 			continue;
 
 		if ((! file_list->priv->show_dot_files && file_is_hidden (name_only))
-		    || ! (mime_type_is_image (mime_type) || mime_type_is_video (mime_type)))
+		    || ! (mime_type_is_image (mime_type) || 
+			  mime_type_is_video (mime_type) ||
+			  mime_type_is_audio (mime_type) ))
 			continue;
 
 		/* if the image is already present invalidate the thumbnail
@@ -1849,7 +1851,6 @@ gth_file_list_exec_next_op (GthFileList *file_list)
 		break;
 	case GTH_FILE_LIST_OP_TYPE_SET_FILTER:
 		gfl_set_filter (file_list);
-		exec_next_op = FALSE;
 		break;
 	}
 	op->file.uri_list = NULL;
