@@ -37,7 +37,7 @@
 
 struct _GthFileViewThumbsPrivate {
 	GthImageList   *ilist;
-	GnomeIconTheme *icon_theme;
+	GtkIconTheme   *icon_theme;
 	GdkPixbuf      *unknown_pixbuf;
 };
 
@@ -134,7 +134,7 @@ gfv_is_frozen (GthFileView  *file_view)
 
 static void
 gfv_insert (GthFileView  *file_view,
-	    int           pos, 
+	    int           pos,
 	    GdkPixbuf    *pixbuf,
 	    const char   *text,
 	    const char   *comment)
@@ -192,13 +192,13 @@ gfv_append_with_data (GthFileView  *file_view,
 
 
 static void
-gfv_remove (GthFileView  *file_view, 
-	    int           pos)
+gfv_remove (GthFileView  *file_view,
+	    gpointer      data)
 {
 	GthFileViewThumbs *gfv_thumbs = (GthFileViewThumbs *) file_view;
 	GthImageList      *ilist = gfv_thumbs->priv->ilist;
 
-	gth_image_list_remove (ilist, pos);
+	gth_image_list_remove (ilist, data);
 }
 
 
@@ -368,7 +368,7 @@ gfv_get_file_list_selection (GthFileView *file_view)
 		FileData *fd = scan->data;
 
 		if ((fd != NULL) && (fd->path != NULL))
-			file_list = g_list_prepend (file_list, 
+			file_list = g_list_prepend (file_list,
 						    g_strdup (fd->path));
 	}
 	file_data_list_free (list);
@@ -457,7 +457,7 @@ gfv_set_image_width (GthFileView     *file_view,
 
 static void
 gfv_set_image_data (GthFileView     *file_view,
-		    int              pos, 
+		    int              pos,
 		    gpointer         data)
 {
 	GthFileViewThumbs *gfv_thumbs = (GthFileViewThumbs *) file_view;
@@ -469,7 +469,7 @@ gfv_set_image_data (GthFileView     *file_view,
 
 static void
 gfv_set_image_data_full (GthFileView     *file_view,
-			 int              pos, 
+			 int              pos,
 			 gpointer         data,
 			 GtkDestroyNotify destroy)
 {
@@ -539,7 +539,7 @@ gfv_get_view_mode (GthFileView *file_view)
 
 static void
 gfv_moveto (GthFileView *file_view,
-	    int          pos, 
+	    int          pos,
 	    double       yalign)
 {
 	GthFileViewThumbs *gfv_thumbs = (GthFileViewThumbs *) file_view;
@@ -561,8 +561,8 @@ gfv_image_is_visible (GthFileView *file_view,
 
 
 static int
-gfv_get_image_at (GthFileView *file_view, 
-		  int          x, 
+gfv_get_image_at (GthFileView *file_view,
+		  int          x,
 		  int          y)
 {
 	GthFileViewThumbs *gfv_thumbs = (GthFileViewThumbs *) file_view;
@@ -597,7 +597,10 @@ gfv_set_visible_func (GthFileView    *file_view,
                       GthVisibleFunc  func,
                       gpointer        data)
 {
-	/* FIXME */
+	GthFileViewThumbs *gfv_thumbs = (GthFileViewThumbs *) file_view;
+	GthImageList      *ilist = gfv_thumbs->priv->ilist;
+
+	gth_image_list_set_visible_func (ilist, func, data);
 }
 
 
@@ -704,14 +707,6 @@ comp_func_comment (gconstpointer  ptr1, gconstpointer  ptr2)
 }
 
 
-static int
-comp_func_none (gconstpointer  ptr1,
-		gconstpointer  ptr2)
-{
-	return 0;
-}
-
-
 static GCompareFunc
 get_compfunc_from_method (GthSortMethod sort_method)
 {
@@ -734,12 +729,12 @@ get_compfunc_from_method (GthSortMethod sort_method)
 		func = comp_func_comment;
 		break;
 	case GTH_SORT_METHOD_BY_EXIF_DATE:
-		func = comp_func_exif_date;	
-		break;	
+		func = comp_func_exif_date;
+		break;
 	case GTH_SORT_METHOD_NONE:
 	case GTH_SORT_METHOD_MANUAL:
 	default:
-		func = comp_func_none;
+		func = gth_sort_none;
 		break;
 	}
 
@@ -775,7 +770,7 @@ gfv_unsorted (GthFileView *file_view)
 
 
 static void
-gfv_image_activated (GthFileView *file_view, 
+gfv_image_activated (GthFileView *file_view,
 		     int          pos)
 {
 	GthFileViewThumbs *gfv_thumbs = (GthFileViewThumbs *) file_view;
@@ -786,7 +781,7 @@ gfv_image_activated (GthFileView *file_view,
 
 
 static void
-gfv_set_cursor (GthFileView *file_view, 
+gfv_set_cursor (GthFileView *file_view,
 		int          pos)
 {
 	GthFileViewThumbs *gfv_thumbs = (GthFileViewThumbs *) file_view;
@@ -821,11 +816,11 @@ get_default_icon_size (GtkWidget *widget)
 static GdkPixbuf *
 create_unknown_pixbuf (GthFileViewThumbs *gfv_thumbs)
 {
-	int         icon_size;
-	char       *icon_name;
-	char       *icon_path;
-	GdkPixbuf  *pixbuf = NULL;
-	int         width, height;
+	GtkIconInfo *icon_info = NULL;
+	int          icon_size;
+	char        *icon_name;
+	GdkPixbuf   *pixbuf = NULL;
+	int          width, height;
 
 	icon_size = get_default_icon_size (GTK_WIDGET (gfv_thumbs->priv->ilist));
 
@@ -837,22 +832,21 @@ create_unknown_pixbuf (GthFileViewThumbs *gfv_thumbs)
 				       "image/*",
 				       GNOME_ICON_LOOKUP_FLAGS_NONE,
 				       NULL);
-	icon_path = gnome_icon_theme_lookup_icon (gfv_thumbs->priv->icon_theme,
+	icon_info = gtk_icon_theme_lookup_icon (gfv_thumbs->priv->icon_theme,
 						  icon_name,
 						  icon_size,
-						  NULL,
-						  NULL);
+						  0);
 	g_free (icon_name);
 
-	if (icon_path != NULL) {
-		pixbuf = gdk_pixbuf_new_from_file (icon_path, NULL);
-		g_free (icon_path);
+	if (icon_info != NULL) {
+		pixbuf = gtk_icon_info_load_icon (icon_info, NULL);
+		gtk_icon_info_free (icon_info);
 	}
 
 	if (pixbuf == NULL)
-		pixbuf = gdk_pixbuf_new_from_inline (-1, 
-						     dir_16_rgba, 
-						     FALSE, 
+		pixbuf = gdk_pixbuf_new_from_inline (-1,
+						     dir_16_rgba,
+						     FALSE,
 						     NULL);
 
 	width = gdk_pixbuf_get_width (pixbuf);
@@ -886,7 +880,7 @@ gfv_update_icon_theme (GthFileView *file_view)
 {
 	GthFileViewThumbs *gfv_thumbs = (GthFileViewThumbs *) file_view;
 
-	if (gfv_thumbs->priv->unknown_pixbuf != NULL) 
+	if (gfv_thumbs->priv->unknown_pixbuf != NULL)
 		g_object_unref (gfv_thumbs->priv->unknown_pixbuf);
 
 	gfv_thumbs->priv->unknown_pixbuf = create_unknown_pixbuf (gfv_thumbs);
@@ -987,7 +981,6 @@ gth_file_view_thumbs_finalize (GObject *object)
 
 	gfv_thumbs = (GthFileViewThumbs*) object;
 
-	g_object_unref (gfv_thumbs->priv->icon_theme);
 	g_object_unref (gfv_thumbs->priv->unknown_pixbuf);
 	g_free (gfv_thumbs->priv);
 
@@ -1100,7 +1093,7 @@ gth_file_view_thumbs_get_type (void)
 }
 
 
-static void 
+static void
 selection_changed_cb (GthImageList      *image_list,
 		      GthFileViewThumbs *gfv_thumbs)
 {
@@ -1149,8 +1142,7 @@ gth_file_view_thumbs_new (guint image_width)
 
 	/**/
 
-	gfv_thumbs->priv->icon_theme = gnome_icon_theme_new ();
-	gnome_icon_theme_set_allow_svg (gfv_thumbs->priv->icon_theme, TRUE);
+	gfv_thumbs->priv->icon_theme = gtk_icon_theme_get_default ();
 	gfv_thumbs->priv->unknown_pixbuf = create_unknown_pixbuf (gfv_thumbs);
 
 	return GTH_FILE_VIEW (gfv_thumbs);
